{*****************************************}
{* Main unit for LogicGates2 application *}
{*****************************************}

unit logic2;

// Implementation of the interactive graphics:
//   - the circuit layout is constituted by a mixture of shapes and images
//   - the LEDs are colored ellipses; different color styles are used for on/off status
//   - the movement of the switches is done by changing the vertical position (TOP property) of the corresponding shapes
//   - the switch shapes being very small and difficult to click by the user, I used a transperant image, placed over them;
//     the OnClick event of the image is used to trigger the actions to be done when the corresponding switch has been clicked.

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls, Menus, ExtCtrls, xor_impl1, xor_impl2;

type
  {**********}
  { TfLogic2 }
  {**********}
  TfLogic2 = class(TForm)
    mMenu: TMainMenu;
    mFile, mFileExit: TMenuItem;
    mHelp, mHelpHelp, mHelpAbout: TMenuItem;
    StaticText1: TStaticText;
    Label1, Label2: TLabel;
    Memo1, Memo2: TMemo;
    btShow1: TButton;
    btShow2: TButton;
    procedure mFileExitClick(Sender: TObject);
    procedure mHelpAboutClick(Sender: TObject);
    procedure mHelpHelpClick(Sender: TObject);
    procedure btShow1Click(Sender: TObject);
    procedure btShow2Click(Sender: TObject);
  end;

var
  fLogic2: TfLogic2;

implementation

{$R *.lfm}

{**********}
{ TfLogic2 }
{**********}

{ Menu item "File > Exit": Exit the application }

procedure TfLogic2.mFileExitClick(Sender: TObject);

begin
  Close;
end;

{ Menu item "Help > Help": Display brief Help text }

procedure TfLogic2.mHelpHelpClick(Sender: TObject);

var
  S: string;

begin
  S := 'Click the switches to open/close them. If closed, the current flows; green LED "on" indicate high input. ';
  S += 'The yellow LED indicate the output state of the intermediate gates = the input state of the final gate. ';
  S += 'The red output LED goes on/off as previews the XOR logic.';
  MessageDlg('"LogicGates2" Help', S, mtInformation, [mbOK], 0);
end;

{ Menu item "Help > About": Display About text }

procedure TfLogic2.mHelpAboutClick(Sender: TObject);

var
  S: string;

begin
  S := 'Logic gates circuits:' + LineEnding;
  S += 'Making XOR gates based on Boolean algebra.' + LineEnding + LineEnding;
  S += 'Version 1.0.2, © allu, June 2018 - August 2021.';
  MessageDlg('About "LogicGates2"', S, mtInformation, [mbOK], 0);
end;

{ Buttons "Show": Show XOR implementation (1 or 2) }

procedure TfLogic2.btShow1Click(Sender: TObject);

begin
  fXOR1.ShowModal;
end;

procedure TfLogic2.btShow2Click(Sender: TObject);

begin
  fXOR2.ShowModal;
end;

end.

